View source: R/imagePreProcessing.R
| imagePreProcessing | R Documentation |
Preprocessing the passed image
imagePreProcessing(zpFilepath)
zpFilepath |
Filepath to the zooplankton image to be processed |
extractedImage The section of the image extracted by the algorithm, or NULL if the image was corrupted
## Not run:
zpFilepath <- 'Users/$(whoami)/Images/ZooplanktonImages/ostracod1.png'
ostracod1Image <- imagePreProcessing(zpFilepath)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.