unpack_processedDataset: unpack_processedDataset

View source: R/unpack_processedDataset.R

unpack_processedDatasetR Documentation

unpack_processedDataset

Description

Unpacking the processed zooplankton dataset to a specific directory. The result will be a directory named "processedDataset" being put the specified save directory, containing all the image files from the processed dataset that comes with this package

Usage

unpack_processedDataset(saveDir)

Arguments

saveDir

(String) Directory to save the processed dataset to

Examples

## Not run: 
saveDir <- 'Users/$(whoami)/Images/ZooplanktonImages/'
unpack_processedDataset(saveDir)

## End(Not run)

ZooID documentation built on May 29, 2024, 2:57 a.m.