unpack_unprocessedDataset: unpack_unprocessedDataset

View source: R/unpack_unprocessedDataset.R

unpack_unprocessedDatasetR Documentation

unpack_unprocessedDataset

Description

Unpacking the unprocessed zooplankton dataset to a specific directory The result will be a directory named "unprocessedDataset" being put in the specified save directory, containing all the image files from the dataset that comes with this package, but before processing was applied

Usage

unpack_unprocessedDataset(saveDir)

Arguments

saveDir

(String) Directory to save the unprocessed dataset to

Examples

## Not run: 
saveDir <- 'Users/$(whoami)/Images/ZooplanktonImages/'
unpack_unprocessedDataset(saveDir)

## End(Not run)

ZooID documentation built on May 29, 2024, 2:57 a.m.