View source: R/unpack_processedDataset.R
| unpack_processedDataset | R Documentation |
Unpacking the processed zooplankton dataset to a specific directory. The result will be a directory named "processedDataset" being put the specified save directory, containing all the image files from the processed dataset that comes with this package
unpack_processedDataset(saveDir)
saveDir |
(String) Directory to save the processed dataset to |
## Not run:
saveDir <- 'Users/$(whoami)/Images/ZooplanktonImages/'
unpack_processedDataset(saveDir)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.