View source: R/unpack_unprocessedDataset.R
| unpack_unprocessedDataset | R Documentation |
Unpacking the unprocessed zooplankton dataset to a specific directory The result will be a directory named "unprocessedDataset" being put in the specified save directory, containing all the image files from the dataset that comes with this package, but before processing was applied
unpack_unprocessedDataset(saveDir)
saveDir |
(String) Directory to save the unprocessed dataset to |
## Not run:
saveDir <- 'Users/$(whoami)/Images/ZooplanktonImages/'
unpack_unprocessedDataset(saveDir)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.